// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module provides terms for `Lexicon Model for Ontologies - LIngusitic MEtadata (LIME)` vocabulary
//!
//! This module requires `ns-lime` feature to be enabled.
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**|Lexicon Model for Ontologies - LIngusitic MEtadata (LIME)|
//! |**Prefix**|lime|
//! |**Namespace base IRI**|<https://www.w3.org/ns/lemon/lime#>|
//! |**Description**|LIME (LInguistic MEtadata) is a vocabulary for expressing linguistic metadata about linguistic resources and linguistically grounded datasets.|
//! |**Is defined by**|<http://rdf.greggkellogg.net/distiller?command=serialize&output_format=ntriples&url=https:%2F%2Fwww.w3.org%2Fns%2Flemon%2Flime&raw>|
//!

use crate::namespace;

namespace!(
    "https://www.w3.org/ns/lemon/lime#",;
    /// ``: 
    NAMESPACE_BASE, ""
);
